@@ -14,6 +14,9 @@ public:
     QAttachmentWidget(QString fileName, qint64 fileSize, QWidget *parent = 0);
     ~QAttachmentWidget();
 
+    void setAudioType();
+    void setPdfType();
+
     static QByteArray toPng(QAttachmentWidget* widget);
 private:
     Ui::QAttachmentWidgetClass ui;
