@@ -50,9 +50,11 @@ void QNoteSearchDialog::openTagSelectionDialog()
 void QNoteSearchDialog::openNotebookSelectionDialog()
 {
 	QNotebookPickList dlg(trUtf8("All Notebooks"), this);
+	dlg.loadNotebooks();
 	if(dlg.exec() == QDialog::Rejected)
 		return;
 
+	selectedNotebook.clear();
 	selectedNotebook.append(dlg.getSelectedName());
 	selectedNotebook.append(dlg.getSelectedGuid());
 
