@@ -512,20 +512,24 @@ void QResourceHandlerDialog::previewResource()
 
 	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(m_resourceHash.toAscii()).data()) == true)
 	{
-		if(r.mime == "application/pdf")
+		switch(QEnmlContentHandler::decodeEnmlMediaType(QString::fromStdString(r.mime))) {
+		case QEnmlContentHandler::MT_PDF:
 		{
 			QPdfPreviewDialog dlg(r, this);
 			dlg.exec();
 		}
-		else if(r.mime == "audio/mpeg" || r.mime == "audio/wav")
+		break;
+		case QEnmlContentHandler::MT_AUDIO:
 		{
 			QAudioPreviewDialog dlg(r, this);
 			dlg.exec();
 		}
-		else
+		break;
+		default:
 		{
 			QvernoteWindow::displayError(parentWidget(), trUtf8("Preview is unavailable for media type"), QString::fromStdString(r.mime));
 		}
+		}
 	}
 
 	close();
