@@ -22,6 +22,8 @@ public slots:
 	void onSaveSettingsClick();
 	void onDropDBClick();
 	void deleteThumbnails();
+	void selectBlacklistedNotebooks();
+	void onBlacklistedNotebookSelected(bool, QString, QString);
 
 	void onDisplayError(QString, QString);
 	void onDisplayInfo(QString);
@@ -48,12 +50,15 @@ private:
     QMaemo5ListPickSelector *displayOrientationSelector;
     QMaemo5ListPickSelector *protocolSelector;
     QMaemo5ListPickSelector *notesViewSelector;
+	QMaemo5ListPickSelector *maxNoteCountSelector;
     QMaemo5ListPickSelector	*mapsProviderSelector;
 
+    QPushButton pbBlacklistedNotebooks;
     QPushButton	pbDeleteThumbs;
     QPushButton	pbDropDB;
     QFutureWatcher<void> watcher;
     QFuture<void> future;
+    QStringList	m_slBlacklistedNotebooks;
 };
 
 #endif // QOPTIONSDIALOG_H
