@@ -21,13 +21,15 @@ public:
 
 public slots:
 	void addNewTag();
+	void sortName();
 
 private:
     Ui::QTagSelectorDialogClass ui;
     vector<string> m_vTagNames;
-    vector<string> tagGuids;
+    //vector<string> tagGuids;
     QvernoteAPI* m_hEvernote;
     QRect geom;
+    bool	sortOrder;
 };
 
 #endif // QTAGSELECTORDIALOG_H
